@@ -42,7 +42,7 @@ ro_dir = image_prefix + "clitest_rodir"
 ro_img = "%s/cli_exist3ro.img" % ro_dir
 ro_noexist_img = "%s/idontexist.img" % ro_dir
 compare_xmldir = "%s/compare" % xmldir
-virtconv_out = "virtconv-outdir"
+virtconv_out = "/tmp/__virtinst_tests__virtconv-outdir"
 
 # Images that will be created by virt-install/virt-clone, and removed before
 # each run
@@ -163,7 +163,7 @@ args_dict = {
         "--file %(NEWIMG1)s --file-size .00001 --nonsparse",
 
         # Existing disk, lots of opts
-        "--disk path=%(EXISTIMG1)s,perms=ro,size=.0001,cache=writethrough",
+        "--disk path=%(EXISTIMG1)s,perms=ro,size=.0001,cache=writethrough,io=threads",
         # Existing disk, rw perms
         "--disk path=%(EXISTIMG1)s,perms=rw",
         # Existing floppy
@@ -403,8 +403,8 @@ args_dict = {
         "--vcpus 4 --cpuset=auto",
         # Ram overcommit
         "--ram 100000000000",
-        # maxvcpus
-        "--vcpus 5,maxvcpus=10",
+        # maxvcpus, --check-cpu shouldn't error
+        "--vcpus 5,maxvcpus=10 --check-cpu",
         # Topology
         "--vcpus 4,cores=2,threads=2,sockets=2",
         # Topology auto-fill
@@ -502,6 +502,12 @@ args_dict = {
         ("--hvm --nodisks --pxe --print-step all", "simple-pxe"),
         # HVM windows install with disk
         ("--hvm --cdrom %(EXISTIMG2)s --file %(EXISTIMG1)s --os-variant win2k3 --wait 0 --vcpus cores=4", "w2k3-cdrom"),
+        # Lot's of devices
+        ("--hvm --pxe "
+         "--disk %(EXISTIMG1)s,cache=writeback,io=threads,perms=sh "
+         "--disk %(NEWIMG1)s,sparse=false,size=.001,perms=ro "
+         "--serial tcp,host=:2222,mode=bind,protocol=telnet ",
+         "many-devices"),
       ],
 
      }, # category "misc"
@@ -696,7 +702,8 @@ args_dict = {
         # XML w/ managed storage, specify managed path
         "--original-xml %(CLONE_STORAGE_XML)s --file %(MANAGEDNEW1)s",
         # XML w/ managed storage, specify managed path across pools
-        "--original-xml %(CLONE_STORAGE_XML)s --file /cross-pool/clonevol",
+        # XXX: Libvirt test driver doesn't support cloning across pools
+        #"--original-xml %(CLONE_STORAGE_XML)s --file /cross-pool/clonevol",
         # XML w/ non-existent storage, with --preserve
         "--original-xml %(CLONE_NOEXIST_XML)s --file %(EXISTIMG1)s --preserve",
       ],
@@ -900,8 +907,12 @@ args_dict = {
         "%(VC_IMG1)s -o virt-image -D foobarfmt %(VIRTCONV_OUT)s",
         # virt-image to ovf (has no output formatter)
         "%(VC_IMG1)s -o ovf %(VIRTCONV_OUT)s",
-     ]
+     ],
 
+     "compare": [
+        # virt-image to default (virt-image) w/ no convert
+        ("%(VC_IMG1)s %(VIRTCONV_OUT)s", "convert-default"),
+     ],
     }, # category 'misc'
 
   }, # app 'virt-conver'
@@ -920,10 +931,6 @@ def runcomm(comm):
             print ret[1]
             print "\n"
 
-        if not debug:
-            sys.stdout.write(".")
-            sys.stdout.flush()
-
         return ret
     except Exception, e:
         return (-1, str(e))
@@ -932,6 +939,16 @@ def run_prompt_comm(comm):
     print comm
     os.system(comm % test_files)
 
+def write_pass():
+    if not debug:
+        sys.stdout.write(".")
+        sys.stdout.flush()
+
+def write_fail():
+    if not debug:
+        sys.stdout.write("F")
+        sys.stdout.flush()
+
 def assertPass(comm):
     ret = runcomm(comm)
     if ret[0] is not 0:
@@ -951,8 +968,38 @@ def assertFail(comm):
     return ret
 
 
+class Command(object):
+    def __init__(self, cmdstr):
+        self.cmdstr = cmdstr
+        self.check_success = True
+        self.compare_file = None
+
+    def run(self):
+        filename = self.compare_file
+        err = None
+
+        try:
+            if self.check_success:
+                ignore, output = assertPass(self.cmdstr)
+            else:
+                ignore, output = assertFail(self.cmdstr)
+
+            if filename:
+                # Uncomment to generate new test files
+                if not os.path.exists(filename):
+                    file(filename, "w").write(output)
+
+                utils.diff_compare(output, filename)
+
+            write_pass()
+        except AssertionError, e:
+            write_fail()
+            err = self.cmdstr + "\n" + str(e)
+
+        return err
+
 # Setup: build cliarg dict, which uses
-def run_tests(do_app, do_category):
+def run_tests(do_app, do_category, error_ret):
     if do_app and do_app not in args_dict.keys():
         raise ValueError("Unknown app '%s'" % do_app)
 
@@ -993,15 +1040,21 @@ def run_tests(do_app, do_category):
             catdict = unique[category]
             category_args = catdict["args"]
 
+            cmdlist = []
+
             for optstr in catdict["valid"]:
                 cmdstr = "./%s %s %s %s" % (app, globalargs,
                                             category_args, optstr)
-                assertPass(cmdstr)
+                cmd = Command(cmdstr)
+                cmd.check_success = True
+                cmdlist.append(cmd)
 
             for optstr in catdict["invalid"]:
                 cmdstr = "./%s %s %s %s" % (app, globalargs,
                                             category_args, optstr)
-                assertFail(cmdstr)
+                cmd = Command(cmdstr)
+                cmd.check_success = False
+                cmdlist.append(cmd)
 
             for optstr, filename in catdict.get("compare") or []:
                 filename = "%s/%s.xml" % (compare_xmldir, filename)
@@ -1025,25 +1078,19 @@ def run_tests(do_app, do_category):
                     if not cmdstr.count("--print-xml"):
                         cmdstr += " --print-xml"
 
-                if not cmdstr.count(fakeuri):
+                if app != "virt-convert" and not cmdstr.count(fakeuri):
                     cmdstr += " --connect %s" % fakeuri
 
-                check_fail = filename.endswith("fail.xml")
+                cmd = Command(cmdstr)
+                cmd.check_success = not filename.endswith("fail.xml")
+                cmd.compare_file = filename
+                cmdlist.append(cmd)
 
-                try:
-                    if check_fail:
-                        ignore, output = assertFail(cmdstr)
-                    else:
-                        ignore, output = assertPass(cmdstr)
-
-                    # Uncomment to generate new test files
-                    if not os.path.exists(filename):
-                        file(filename, "w").write(output)
-
-                    utils.diff_compare(output, filename)
-                except:
-                    print cmdstr
-                    raise
+            # Run commands
+            for cmd in cmdlist:
+                err = cmd.run()
+                if err:
+                    error_ret.append(err)
 
 def main():
     # CLI Args
@@ -1079,12 +1126,16 @@ def main():
     os.system("chmod 444 %s" % ro_img)
     os.system("chmod 555 %s" % ro_dir)
 
+    error_ret = []
     try:
-        run_tests(do_app, do_category)
+        run_tests(do_app, do_category, error_ret)
     finally:
         cleanup()
+        for err in error_ret:
+            print err + "\n\n"
 
-    print "\nAll tests completed successfully."
+    if not error_ret:
+        print "\nAll tests completed successfully."
 
 def cleanup():
     # Cleanup files
@@ -1093,4 +1144,7 @@ def cleanup():
         os.system("rm -rf %s > /dev/null 2>&1" % i)
 
 if __name__ == "__main__":
-    main()
+    try:
+        main()
+    except KeyboardInterrupt:
+        print "Tests interrupted"
