@@ -725,9 +725,11 @@ class TestXMLConfig(unittest.TestCase):
         g.disks.append(VirtualDisk(conn=g.conn, path="/dev/loop0",
                                    device=VirtualDisk.DEVICE_FLOPPY,
                                    driverName="phy", driverCache="none"))
-        g.disks.append(VirtualDisk(conn=g.conn, path="/dev/loop0",
-                                   bus="virtio", driverName="qemu",
-                                   driverType="qcow2", driverCache="none"))
+        disk = VirtualDisk(conn=g.conn, path="/dev/loop0",
+                           bus="virtio", driverName="qemu",
+                           driverType="qcow2", driverCache="none")
+        disk.driver_io = "threads"
+        g.disks.append(disk)
 
         self._compare(g, "boot-many-disks2", False)
 
@@ -890,8 +892,12 @@ class TestXMLConfig(unittest.TestCase):
                                                    VirtualCharDevice.DEV_PARALLEL,
                                                    VirtualCharDevice.CHAR_UNIX)
         cdev2.source_path = "/tmp/foobar"
+        cdev3 = VirtualCharDevice.get_dev_instance(g.conn,
+                                                   VirtualCharDevice.DEV_CHANNEL,
+                                                   VirtualCharDevice.CHAR_SPICEVMC)
         g.add_device(cdev1)
         g.add_device(cdev2)
+        g.add_device(cdev3)
 
         # Video Devices
         vdev1 = VirtualVideoDevice(g.conn)
@@ -1019,5 +1025,22 @@ class TestXMLConfig(unittest.TestCase):
         self.conn_function_wrappers(g, fargs, func=self._testInstall,
                                     conn_uri=qemu_uri)
 
+    def testCreateDisk(self):
+        """
+        Doesn't really belong here, but what the hell :)
+        """
+        path = "/tmp/__virtinst_create_test__.img"
+        sizegigs = .001
+        sizebytes = long(sizegigs * 1024L * 1024L * 1024L)
+
+        for sparse in [True, False]:
+            disk = VirtualDisk(conn=conn, path=path, size=sizegigs,
+                               sparse=sparse)
+            disk.setup()
+
+            actualsize = long(os.path.getsize(path))
+            os.unlink(path)
+            self.assertEquals(sizebytes, actualsize)
+
 if __name__ == "__main__":
     unittest.main()
