@@ -62,7 +62,7 @@ class XMLParseTest(unittest.TestCase):
         if failed:
             raise AssertionError("Roundtrip parse tests failed:\n%s" % error)
 
-    def _set_and_check(self, obj, param, initval, newval="SENTINEL"):
+    def _set_and_check(self, obj, param, initval, *args):
         """
         Check expected initial value obj.param == initval, then
         set newval, and make sure it is returned properly
@@ -70,15 +70,14 @@ class XMLParseTest(unittest.TestCase):
         curval = getattr(obj, param)
         self.assertEquals(initval, curval)
 
-        if newval == "SENTINEL":
-            return
-        setattr(obj, param, newval)
-        curval = getattr(obj, param)
-        self.assertEquals(newval, curval)
+        for newval in args:
+            setattr(obj, param, newval)
+            curval = getattr(obj, param)
+            self.assertEquals(newval, curval)
 
     def _make_checker(self, obj):
-        def check(name, initval, newval="SENTINEL"):
-            return self._set_and_check(obj, name, initval, newval)
+        def check(name, initval, *args):
+            return self._set_and_check(obj, name, initval, *args)
         return check
 
     def testAlterGuest(self):
@@ -131,6 +130,15 @@ class XMLParseTest(unittest.TestCase):
         check("apic", True, False)
         check("pae", False, True)
 
+        def feature_checker(prop, origval, newval):
+            self.assertEqual(guest.features[prop], origval)
+            guest.features[prop] = newval
+            self.assertEqual(guest.features[prop], newval)
+
+        feature_checker("acpi", False, False)
+        feature_checker("apic", False, True)
+        feature_checker("pae", True, False)
+
         check = self._make_checker(guest.cpu)
         check("match", "exact", "strict")
         check("model", "footest", "qemu64")
@@ -247,6 +255,8 @@ class XMLParseTest(unittest.TestCase):
         check("path", None, "/default-pool/default-vol")
         check("shareable", False, True)
         check("driver_cache", None, "writeback")
+        check("driver_io", None, "threads")
+        check("driver_io", "threads", "native")
 
         self._alter_compare(guest.get_config_xml(), outfile)
 
@@ -352,6 +362,7 @@ class XMLParseTest(unittest.TestCase):
         dev2 = guest.get_devices("interface")[1]
         dev3 = guest.get_devices("interface")[2]
         dev4 = guest.get_devices("interface")[3]
+        dev5 = guest.get_devices("interface")[4]
 
         check = self._make_checker(dev1)
         check("type", "user")
@@ -363,9 +374,9 @@ class XMLParseTest(unittest.TestCase):
 
         check = self._make_checker(dev2)
         self.assertEquals(dev2.get_source(), "default")
-        check("type", "network", "bridge")
         check("network", "default", None)
         check("bridge", None, "newbr0")
+        check("type", "network", "bridge")
         check("model", "e1000", "virtio")
 
         check = self._make_checker(dev3)
@@ -383,6 +394,19 @@ class XMLParseTest(unittest.TestCase):
         check("target_dev", "nic03", None)
         self.assertEquals(dev4.get_source(), "eth1")
 
+        check = self._make_checker(dev5)
+        check("type", "direct")
+        check("source_dev", "eth0.1")
+
+        virtualport = dev5.virtualport
+        check = self._make_checker(virtualport)
+        check("type", "802.1Qbg")
+        check("managerid", "12", "11")
+        check("typeid", "1193046", "1193047")
+        check("typeidversion", "1", "2")
+        check("instanceid", "09b11c53-8b5c-4eeb-8f00-d84eaa0aaa3b",
+                            "09b11c53-8b5c-4eeb-8f00-d84eaa0aaa4f")
+
         self._alter_compare(guest.get_config_xml(), outfile)
 
     def testAlterInputs(self):
