@@ -522,11 +522,22 @@ class Capabilities(object):
         sufficiently provided, so we will return True in cases that we
         aren't sure.
         """
+        has_hvm_guests = False
+        for g in self.guests:
+            if g.os_type == "hvm":
+                has_hvm_guests = True
+                break
+
         # Obvious case of feature being specified
         if (self.host.features["vmx"] == FEATURE_ON or
             self.host.features["svm"] == FEATURE_ON):
             return True
 
+        # Xen seems to block the vmx/svm feature bits from cpuinfo?
+        # so make sure no hvm guests are listed
+        if self._is_xen() and has_hvm_guests:
+            return True
+
         # If there is other features, but no virt bit, then HW virt
         # isn't supported
         if len(self.host.features.names()):
