@@ -369,7 +369,7 @@ class Guest(XMLBuilderDomain.XMLBuilderDomain):
         maxvcpus = _util.get_max_vcpus(self.conn, self.type)
         val = int(val)
         if val < 1:
-            raise ValueError(_("Number of vcpus must be a postive integer."))
+            raise ValueError(_("Number of vcpus must be a positive integer."))
         if val > maxvcpus:
             raise ValueError(_("Number of vcpus must be no greater than %d "
                                "for this vm type.") % maxvcpus)
@@ -889,20 +889,11 @@ class Guest(XMLBuilderDomain.XMLBuilderDomain):
 
         return emu_xml
 
-    def _get_features_xml(self):
+    def _get_features_xml(self, features):
         """
         Return features (pae, acpi, apic) xml
         """
-        defaults = {}
-        if self.is_hvm():
-            for f in ["acpi", "apic"]:
-                defaults[f] = self._lookup_osdict_key(f)
-
-            caps = self._get_caps()
-            if caps:
-                defaults["pae"] = caps.support_pae()
-
-        return self.features.get_xml_config(defaults)
+        return features.get_xml_config()
 
     def _get_cpu_xml(self):
         """
@@ -1014,6 +1005,7 @@ class Guest(XMLBuilderDomain.XMLBuilderDomain):
         for dev in origdevs:
             newdev = copy.copy(dev)
             devs.append(newdev)
+        tmpfeat = copy.copy(self.features)
 
         def get_transient_devices(devtype):
             return self._dev_build_list(devtype, devs)
@@ -1022,7 +1014,8 @@ class Guest(XMLBuilderDomain.XMLBuilderDomain):
 
         # Set device defaults so we can validly generate XML
         self._set_defaults(get_transient_devices,
-                           remove_transient_device)
+                           remove_transient_device,
+                           tmpfeat)
 
         if install:
             action = "destroy"
@@ -1053,7 +1046,7 @@ class Guest(XMLBuilderDomain.XMLBuilderDomain):
         xml = add("  <uuid>%s</uuid>" % self.uuid)
         xml = add(desc_xml)
         xml = add("  %s" % osblob)
-        xml = add(self._get_features_xml())
+        xml = add(self._get_features_xml(tmpfeat))
         xml = add(self._get_cpu_xml())
         xml = add(self._get_clock_xml())
         xml = add("  <on_poweroff>destroy</on_poweroff>")
@@ -1364,9 +1357,10 @@ class Guest(XMLBuilderDomain.XMLBuilderDomain):
         The install process will call a non-persistent version, so calling
         this manually isn't required.
         """
-        self._set_defaults(self.get_devices, self.remove_device)
+        self._set_defaults(self.get_devices, self.remove_device,
+                           self.features)
 
-    def _set_hvm_defaults(self, devlist_func):
+    def _set_hvm_defaults(self, devlist_func, features):
         disktype = VirtualDevice.VIRTUAL_DEV_DISK
         nettype = VirtualDevice.VIRTUAL_DEV_NET
         disk_bus  = self._lookup_device_param(disktype, "bus")
@@ -1385,6 +1379,14 @@ class Guest(XMLBuilderDomain.XMLBuilderDomain):
         if self.clock.offset == None:
             self.clock.offset = self._lookup_osdict_key("clock")
 
+        if features["acpi"] is None:
+            features["acpi"] = self._lookup_osdict_key("acpi")
+        if features["apic"] is None:
+            features["apic"] = self._lookup_osdict_key("apic")
+        if features["pae"] is None and self._get_caps():
+            features["pae"] = self._get_caps().support_pae()
+
+
     def _set_pv_defaults(self, devlist_func, remove_func):
         # Default file backed PV guests to tap driver
         for d in devlist_func(VirtualDevice.VIRTUAL_DEV_DISK):
@@ -1403,15 +1405,17 @@ class Guest(XMLBuilderDomain.XMLBuilderDomain):
             if hasattr(d, "virtinst_default"):
                 remove_func(d)
 
-    def _set_defaults(self, devlist_func, remove_func):
+    def _set_defaults(self, devlist_func, remove_func, features):
         if self.is_hvm():
-            self._set_hvm_defaults(devlist_func)
+            self._set_hvm_defaults(devlist_func, features)
         if self.is_xen():
             self._set_pv_defaults(devlist_func, remove_func)
 
         soundtype = VirtualDevice.VIRTUAL_DEV_AUDIO
         videotype = VirtualDevice.VIRTUAL_DEV_VIDEO
         inputtype = VirtualDevice.VIRTUAL_DEV_INPUT
+        gfxtype = VirtualDevice.VIRTUAL_DEV_GRAPHICS
+        channeltype = VirtualDevice.VIRTUAL_DEV_CHANNEL
 
         # Set default input values
         input_type = self._lookup_device_param(inputtype, "type")
@@ -1442,11 +1446,35 @@ class Guest(XMLBuilderDomain.XMLBuilderDomain):
                 sound.model = sound_model
 
         # Set video device model
-        video_model  = self._lookup_device_param(videotype, "model_type")
+        # QXL device (only if we use spice) - safe even if guest is VGA only
+        def has_spice():
+            for gfx in devlist_func(gfxtype):
+                if gfx.type == gfx.TYPE_SPICE:
+                    return True
+        if has_spice():
+            video_model  = "qxl"
+        else:
+            video_model  = self._lookup_device_param(videotype, "model_type")
+
         for video in devlist_func(videotype):
             if video.model_type == video.MODEL_DEFAULT:
                 video.model_type = video_model
 
+        # Spice agent channel (only if we use spice)
+        def has_spice_agent():
+            for chn in devlist_func(channeltype):
+                if chn.char_type == chn.CHAR_SPICEVMC:
+                    return True
+
+        if (has_spice() and
+            not has_spice_agent() and
+            support.check_conn_support(self.conn,
+                                       support.SUPPORT_CONN_HV_CHAR_SPICEVMC)):
+            agentdev = VirtualCharDevice.get_dev_instance(self.conn,
+                                            VirtualCharDevice.DEV_CHANNEL,
+                                            VirtualCharDevice.CHAR_SPICEVMC)
+            self.add_device(agentdev)
+
         # Generate UUID
         if self.uuid is None:
             found = False
@@ -1465,21 +1493,33 @@ class Guest(XMLBuilderDomain.XMLBuilderDomain):
     # Guest Dictionary Helper methods #
     ###################################
 
+    def _is_rhel6(self):
+        emulator = self.emulator or ""
+
+        return (self.type in ["qemu", "kvm"] and
+                emulator.startswith("/usr/libexec/qemu"))
+
     def _lookup_osdict_key(self, key):
         """
         Using self.os_type and self.os_variant to find key in OSTYPES
         @returns: dict value, or None if os_type/variant wasn't set
         """
-        return osdict.lookup_osdict_key(self.conn, self.type, self.os_type,
-                                        self.os_variant, key)
+        return osdict.lookup_osdict_key(self.conn, self.type,
+                                        self.os_type, self.os_variant,
+                                        key)
 
     def _lookup_device_param(self, device_key, param):
         """
         Check the OS dictionary for the prefered device setting for passed
         device type and param (bus, model, etc.)
         """
-        return osdict.lookup_device_param(self.conn, self.type, self.os_type,
-                                          self.os_variant, device_key, param)
+        try:
+            support._set_rhel6(self._is_rhel6())
+            return osdict.lookup_device_param(self.conn, self.type,
+                                              self.os_type, self.os_variant,
+                                              device_key, param)
+        finally:
+            support._set_rhel6(False)
 
 
 def _wait_for_domain(conn, name):
