@@ -33,25 +33,17 @@ class ImageInstallerException(Exception):
 class ImageInstaller(Installer.Installer):
     """Installer for image-based guests"""
     def __init__(self, image, capabilities=None, boot_index=None, conn=None):
-        Installer.Installer.__init__(self, conn=conn)
+        Installer.Installer.__init__(self, conn=conn, caps=capabilities)
 
         self._arch = None
         self._image = image
 
-        # Set capabilities
-        if self.conn:
-            self._capabilities = Cap.parse(self.conn.getCapabilities())
-        elif capabilities:
-            if not isinstance(capabilities, Cap.Capabilities):
-                raise ValueError(_("'capabilities' must be a "
-                                   "Capabilities instance."))
-            self._capabilities = capabilities
-        else:
+        if not (self.conn or self._get_caps()):
             raise ValueError(_("'conn' or 'capabilities' must be specified."))
 
         # Set boot _boot_caps/_boot_parameters
         if boot_index is None:
-            self._boot_caps = match_boots(self._capabilities,
+            self._boot_caps = match_boots(self._get_caps(),
                                      self.image.domain.boots)
             if self._boot_caps is None:
                 raise ImageInstallerException(_("Could not find suitable boot "
@@ -63,8 +55,8 @@ class ImageInstaller(Installer.Installer):
             self._boot_caps = image.domain.boots[boot_index]
 
         # Set up internal caps.guest object
-        self._guest = self._capabilities.guestForOSType(self.boot_caps.type,
-                                                        self.boot_caps.arch)
+        self._guest = self._get_caps().guestForOSType(self.boot_caps.type,
+                                                      self.boot_caps.arch)
         if self._guest is None:
             raise PlatformMatchException(_("Unsupported virtualization type: "
                                            "%s %s" % (self.boot_caps.type,
@@ -112,36 +104,42 @@ class ImageInstaller(Installer.Installer):
     def post_install_check(self, guest):
         return True
 
+    def has_install_phase(self):
+        return False
+
     # Private methods
     def _get_bootdev(self, isinstall, guest):
-        if isinstall:
-            return None
         return self.boot_caps.bootdev
 
     def _make_disks(self):
-        for m in self.boot_caps.drives:
-            p = self._abspath(m.disk.file)
-            s = None
-            if m.disk.size is not None:
-                s = float(m.disk.size)/1024
+        for drive in self.boot_caps.drives:
+            path = self._abspath(drive.disk.file)
+            size = None
+            if drive.disk.size is not None:
+                size = float(drive.disk.size) / 1024
 
             # FIXME: This is awkward; the image should be able to express
             # whether the disk is expected to be there or not independently
             # of its classification, especially for user disks
             # FIXME: We ignore the target for the mapping in m.target
-            if (m.disk.use == ImageParser.Disk.USE_SYSTEM and
-                not os.path.exists(p)):
+            if (drive.disk.use == ImageParser.Disk.USE_SYSTEM and
+                not os.path.exists(path)):
                 raise ImageInstallerException(_("System disk %s does not exist")
-                                              % p)
-            device = VirtualDisk.DEVICE_DISK
-            if m.disk.format == ImageParser.Disk.FORMAT_ISO:
-                device = VirtualDisk.DEVICE_CDROM
-            d = VirtualDisk(p, s,
-                            device = device,
-                            type = VirtualDisk.TYPE_FILE)
-            d.target = m.target
+                                              % path)
 
-            self.install_devices.append(d)
+            device = VirtualDisk.DEVICE_DISK
+            if drive.disk.format == ImageParser.Disk.FORMAT_ISO:
+                device = VirtualDisk.DEVICE_CDROM
+
+
+            disk = VirtualDisk(conn=self.conn,
+                               path=path,
+                               size=size,
+                               device=device,
+                               format=drive.disk.format)
+            disk.target = drive.target
+
+            self.install_devices.append(disk)
 
     def _abspath(self, p):
         return self.image.abspath(p)
