@@ -1164,6 +1164,7 @@ class StorageVolume(StorageObject):
                 if support.is_error_nosupport(e):
                     raise RuntimeError("Libvirt version does not support "
                                        "storage cloning.")
+                raise
             except Exception, e:
                 raise RuntimeError("Couldn't create storage volume "
                                    "'%s': '%s'" % (self.name, str(e)))
@@ -1234,6 +1235,7 @@ class FileVolume(StorageVolume):
 
     formats = ["raw", "bochs", "cloop", "cow", "dmg", "iso", "qcow",
                "qcow2", "vmdk", "vpc"]
+    create_formats = ["raw", "cow", "qcow", "qcow2", "vmdk", "vpc"]
 
     # Register applicable property methods from parent class
     perms = property(StorageObject.get_perms, StorageObject.set_perms)
