@@ -178,19 +178,19 @@ def _check_if_path_managed(conn, path):
         try:
             # Pool may need to be refreshed, but if it errors,
             # invalidate it
-            if pool:
-                pool.refresh(0)
-
+            pool.refresh(0)
             vol, verr = lookup_vol_by_path()
         except Exception, e:
             vol = None
             pool = None
             verr = str(e)
 
-    if not (vol or pool):
+    if not vol:
         # See if path is a pool source, and allow it through
-        pool = _check_if_pool_source(conn, path)
-        path_is_pool = bool(pool)
+        trypool = _check_if_pool_source(conn, path)
+        if trypool:
+            path_is_pool = True
+            pool = trypool
 
     if not vol and not pool:
         if not _util.is_uri_remote(conn.getURI()):
@@ -321,6 +321,7 @@ class VirtualDisk(VirtualDevice):
     types = [TYPE_FILE, TYPE_BLOCK, TYPE_DIR]
 
     _target_props = ["file", "dev", "dir"]
+    io_modes = ["native", "threads"]
 
     @staticmethod
     def disk_type_to_xen_driver_name(disk_type):
@@ -517,7 +518,8 @@ class VirtualDisk(VirtualDevice):
                  readOnly=False, sparse=True, conn=None, volObject=None,
                  volInstall=None, volName=None, bus=None, shareable=False,
                  driverCache=None, selinuxLabel=None, format=None,
-                 validate=True, parsexml=None, parsexmlnode=None, caps=None):
+                 validate=True, parsexml=None, parsexmlnode=None, caps=None,
+                 driverIO=None):
         """
         @param path: filesystem path to the disk image.
         @type path: C{str}
@@ -583,6 +585,7 @@ class VirtualDisk(VirtualDevice):
         self._format = None
         self._driverName = driverName
         self._driverType = driverType
+        self._driver_io = None
         self._target = None
         self._validate = validate
 
@@ -609,6 +612,7 @@ class VirtualDisk(VirtualDevice):
         self._set_driver_cache(driverCache, validate=False)
         self._set_selinux_label(selinuxLabel, validate=False)
         self._set_format(format, validate=False)
+        self._set_driver_io(driverIO, validate=False)
 
         self.__change_storage(self.path,
                               self.vol_object,
@@ -820,6 +824,19 @@ class VirtualDisk(VirtualDevice):
     driver_cache = _xml_property(_get_driver_cache, _set_driver_cache,
                                  xpath="./driver/@cache")
 
+
+    def _get_driver_io(self):
+        return self._driver_io
+    def _set_driver_io(self, val, validate=True):
+        if val is not None:
+            self._check_str(val, "driver_io")
+            if val not in self.io_modes:
+                raise ValueError(_("Unknown io mode '%s'" % val))
+        self.__validate_wrapper("_driver_io", val, validate,
+                                self.driver_io)
+    driver_io = _xml_property(_get_driver_io, _set_driver_io,
+                              xpath="./driver/@io")
+
     # If there is no selinux support on the libvirt connection or the
     # system, we won't throw errors if this is set, just silently ignore.
     def _get_selinux_label(self):
@@ -1230,21 +1247,31 @@ class VirtualDisk(VirtualDevice):
         Helper function which attempts to build self.path
         """
         fd = None
+        path = self.path
+        sparse = self.sparse
 
         try:
             try:
-                fd = os.open(self.path, os.O_WRONLY | os.O_CREAT | os.O_DSYNC)
-                if self.sparse:
+                fd = os.open(path, os.O_WRONLY | os.O_CREAT | os.O_DSYNC)
+
+                if sparse:
                     os.ftruncate(fd, size_bytes)
-                    progresscb.update(self.size)
                 else:
-                    buf = '\x00' * 1024 * 1024 # 1 meg of nulls
-                    for i in range(0, long(self.size * 1024L)):
+                    # 1 meg of nulls
+                    mb = 1024 * 1024
+                    buf = '\x00' * mb
+
+                    left = size_bytes
+                    while left > 0:
+                        if left < mb:
+                            buf = '\x00' * left
+                        left = max(left - mb, 0)
+
                         os.write(fd, buf)
-                        progresscb.update(long(i * 1024L * 1024L))
+                        progresscb.update(size_bytes - left)
             except OSError, e:
                 raise RuntimeError(_("Error creating diskimage %s: %s") %
-                                   (self.path, str(e)))
+                                   (path, str(e)))
         finally:
             if fd is not None:
                 os.close(fd)
@@ -1374,12 +1401,12 @@ class VirtualDisk(VirtualDevice):
             drvxml = ""
             if not self.driver_name is None:
                 drvxml += " name='%s'" % self.driver_name
-
             if not self.driver_type is None:
                 drvxml += " type='%s'" % self.driver_type
-
             if not self.driver_cache is None:
                 drvxml += " cache='%s'" % self.driver_cache
+            if not self.driver_io is None:
+                drvxml += " io='%s'" % self.driver_io
 
             if drvxml:
                 ret += "      <driver%s/>\n" % drvxml
