@@ -81,6 +81,15 @@ class VirtualGraphics(VirtualDevice.VirtualDevice):
 
         return sort_list
 
+    @staticmethod
+    def pretty_type_simple(gtype):
+        if (gtype in [VirtualGraphics.TYPE_VNC,
+                      VirtualGraphics.TYPE_SDL,
+                      VirtualGraphics.TYPE_RDP]):
+            return str(gtype).upper()
+
+        return str(gtype).capitalize()
+
     def __init__(self, type=TYPE_VNC, port=-1, listen=None, passwd=None,
                  keymap=KEYMAP_DEFAULT, conn=None, parsexml=None,
                  parsexmlnode=None, tlsPort=-1, channels=None,
@@ -253,10 +262,12 @@ class VirtualGraphics(VirtualDevice.VirtualDevice):
     channel_record_mode = _get_mode_prop(CHANNEL_TYPE_RECORD)
 
     def _build_xml(self, port=None, listen=None, keymap=None, passwd=None,
-                   display=None, xauth=None, tlsPort=None, autoport=False,
+                   display=None, xauth=None, tlsPort=None, canautoport=False,
                    passwdValidTo=None, socket=None):
 
-        doautoport = (autoport and (port == -1 or tlsPort == -1))
+        doautoport = (canautoport and
+                      (port in [None, -1] and
+                       tlsPort in [None, -1]))
         portxml     = (port != None and (" port='%d'" % port) or "")
         tlsportxml  = (tlsPort != None and (" tlsPort='%d'" % tlsPort) or "")
         autoportxml = (doautoport and " autoport='yes'" or "")
@@ -299,12 +310,15 @@ class VirtualGraphics(VirtualDevice.VirtualDevice):
     def _spice_config(self):
         return self._build_xml(port=self.port, keymap=self.keymap,
                                passwd=self.passwd, listen=self.listen,
-                               tlsPort=self.tlsPort, autoport=True,
+                               tlsPort=self.tlsPort, canautoport=True,
                                passwdValidTo=self.passwdValidTo)
 
     def _vnc_config(self):
         return self._build_xml(port=self.port, keymap=self.keymap,
                                passwd=self.passwd, listen=self.listen,
+                               # VNC supports autoport, but use legacy
+                               # syntax to not break XML tests
+                               canautoport=False,
                                passwdValidTo=self.passwdValidTo,
                                socket=self.socket)
 
