@@ -22,6 +22,7 @@ import libvirt
 
 import _util
 import VirtualDevice
+import XMLBuilderDomain
 from XMLBuilderDomain import _xml_property
 from virtinst import _virtinst as _
 
@@ -44,6 +45,56 @@ def _countMACaddr(vms, searchmac):
         count += _util.get_xml_path(xml, func=count_cb)
     return count
 
+class VirtualPort(XMLBuilderDomain.XMLBuilderDomain):
+
+    def __init__(self, conn, parsexml=None, parsexmlnode=None, caps=None):
+        XMLBuilderDomain.XMLBuilderDomain.__init__(self, conn, parsexml,
+                                                   parsexmlnode, caps=caps)
+        self._type = None
+        self._managerid = None
+        self._typeid = None
+        self._typeidversion = None
+        self._instanceid = None
+
+    def get_type(self):
+        return self._type
+    def set_type(self, val):
+        self._type = val
+    type = _xml_property(get_type, set_type,
+                                  xpath="./virtualport/@type")
+
+    def get_managerid(self):
+        return self._managerid
+    def set_managerid(self, val):
+        self._managerid = val
+    managerid = _xml_property(get_managerid, set_managerid,
+                                  xpath="./virtualport/parameters/@managerid")
+
+    def get_typeid(self):
+        return self._typeid
+    def set_typeid(self, val):
+        self._typeid = val
+    typeid = _xml_property(get_typeid, set_typeid,
+                               xpath="./virtualport/parameters/@typeid")
+
+    def get_typeidversion(self):
+        return self._typeidversion
+    def set_typeidversion(self, val):
+        self._typeidversion = val
+    typeidversion = _xml_property(get_typeidversion, set_typeidversion,
+                               xpath="./virtualport/parameters/@typeidversion")
+
+    def get_instanceid(self):
+        return self._instanceid
+    def set_instanceid(self, val):
+        self._instanceid = val
+    instanceid = _xml_property(get_instanceid, set_instanceid,
+                               xpath="./virtualport/parameters/@instanceid")
+
+    def _get_xml_config(self):
+        # FIXME: This should be implemented, currently we can only parse
+        return ""
+
 class VirtualNetworkInterface(VirtualDevice.VirtualDevice):
 
     _virtual_device_type = VirtualDevice.VirtualDevice.VIRTUAL_DEV_NET
@@ -52,7 +103,9 @@ class VirtualNetworkInterface(VirtualDevice.VirtualDevice):
     TYPE_VIRTUAL    = "network"
     TYPE_USER       = "user"
     TYPE_ETHERNET   = "ethernet"
-    network_types = [TYPE_BRIDGE, TYPE_VIRTUAL, TYPE_USER, TYPE_ETHERNET]
+    TYPE_DIRECT   = "direct"
+    network_types = [TYPE_BRIDGE, TYPE_VIRTUAL, TYPE_USER, TYPE_ETHERNET,
+                     TYPE_DIRECT]
 
     def get_network_type_desc(net_type):
         """
@@ -83,6 +136,7 @@ class VirtualNetworkInterface(VirtualDevice.VirtualDevice):
         self._model = None
         self._target_dev = None
         self._source_dev = None
+        self._virtualport = VirtualPort(conn, parsexml, parsexmlnode, caps)
 
         # Generate _random_mac
         self._random_mac = None
@@ -130,12 +184,30 @@ class VirtualNetworkInterface(VirtualDevice.VirtualDevice):
             return self.network
         if self.type == self.TYPE_BRIDGE:
             return self.bridge
-        if self.type == self.TYPE_ETHERNET:
+        if self.type == self.TYPE_ETHERNET or self.type == self.TYPE_DIRECT:
             return self.source_dev
         if self.type == self.TYPE_USER:
             return None
         return self.network or self.bridge or self.source_dev
 
+    def set_source(self, newsource):
+        """
+        Conveninece function, try to set the relevant <source> value
+        per the network type
+        """
+        if   self.type == self.TYPE_VIRTUAL:
+            self.network = newsource
+        elif self.type == self.TYPE_BRIDGE:
+            self.bridge = newsource
+        elif self.type == self.TYPE_ETHERNET or self.type == self.TYPE_DIRECT:
+            self.source_dev = newsource
+        return
+    source = property(get_source, set_source)
+
+    def _get_virtualport(self):
+        return self._virtualport
+    virtualport = property(_get_virtualport)
+
     def get_type(self):
         return self._type
     def set_type(self, val):
