@@ -43,6 +43,14 @@ try:
 except ImportError:
     selinux = None
 
+def listify(l):
+    if l is None:
+        return []
+    elif type(l) != list:
+        return [ l ]
+    else:
+        return l
+
 def is_vdisk(path):
     if not os.path.exists("/usr/sbin/vdiskadm"):
         return False
@@ -125,17 +133,17 @@ def libvirt_collision(collision_cb, val):
 
 def validate_uuid(val):
     if type(val) is not str:
-        raise ValueError, _("UUID must be a string.")
+        raise ValueError(_("UUID must be a string."))
 
     form = re.match("[a-fA-F0-9]{8}[-]([a-fA-F0-9]{4}[-]){3}[a-fA-F0-9]{12}$",
                     val)
     if form is None:
         form = re.match("[a-fA-F0-9]{32}$", val)
         if form is None:
-            raise ValueError, \
+            raise ValueError(
                   _("UUID must be a 32-digit hexadecimal number. It may take "
                     "the form XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX or may omit "
-                    "hyphens altogether.")
+                    "hyphens altogether."))
 
         else:   # UUID had no dashes, so add them in
             val = (val[0:8] + "-" + val[8:12] + "-" + val[12:16] +
@@ -144,21 +152,21 @@ def validate_uuid(val):
 
 def validate_name(name_type, val):
     if type(val) is not type("string") or len(val) > 50 or len(val) == 0:
-        raise ValueError, _("%s name must be a string between 0 and 50 "
-                            "characters") % name_type
+        raise ValueError(_("%s name must be a string between 0 and 50 "
+                           "characters") % name_type)
     if re.match("^[0-9]+$", val):
-        raise ValueError, _("%s name can not be only numeric characters") % \
-                          name_type
+        raise ValueError(_("%s name can not be only numeric characters") %
+                          name_type)
     if re.match("^[a-zA-Z0-9._-]+$", val) == None:
-        raise ValueError, _("%s name can only contain alphanumeric, '_', '.', "
-                            "or '-' characters") % name_type
+        raise ValueError(_("%s name can only contain alphanumeric, '_', '.', "
+                           "or '-' characters") % name_type)
 
 def validate_macaddr(val):
     if val is None:
         return
 
     if type(val) is not str:
-        raise ValueError, _("MAC address must be a string.")
+        raise ValueError(_("MAC address must be a string."))
 
     form = re.match("^([0-9a-fA-F]{1,2}:){5}[0-9a-fA-F]{1,2}$", val)
     if form is None:
@@ -361,7 +369,7 @@ def default_nic():
 
     return dev
 
-def default_bridge2(conn = None):
+def default_bridge2(conn=None):
     if platform.system() == 'SunOS':
         return ["bridge", default_nic()]
 
@@ -397,6 +405,18 @@ def is_qemu_system(conn):
         return True
     return False
 
+def is_qemu(conn):
+    if not conn:
+        return False
+
+    if type(conn) is str:
+        uri = conn
+    else:
+        uri = conn.getURI()
+
+    scheme = uri_split(uri)[0]
+    return scheme.startswith("qemu")
+
 def parse_node_helper(xml, root_name, callback, exec_class=ValueError):
     """
     Parse the passed XML, expecting root as root_name, and pass the
@@ -432,6 +452,48 @@ def parse_node_helper(xml, root_name, callback, exec_class=ValueError):
 
     return ret
 
+def find_xkblayout(path):
+    """
+    Reads a keyboard layout from a file that defines an XKBLAYOUT
+    variable, e.g. /etc/default/{keyboard,console-setup}.
+    The format of these files is such that they can be 'sourced'
+    in a shell script.
+    """
+
+    kt = None
+    try:
+        f = open(path, "r")
+    except IOError, e:
+        logging.debug('Could not open "%s": %s ' % (path, str(e)))
+    else:
+        keymap_re = re.compile(r'\s*XKBLAYOUT="(?P<kt>[a-z-]+)"')
+        for line in f:
+            m = keymap_re.match(line)
+            if m:
+                kt = m.group('kt')
+                break
+        else:
+            logging.debug("Didn't find keymap in '%s'!" % path)
+        f.close()
+    return kt
+
+def find_keymap_from_etc_default():
+    """
+    Look under /etc/default for the host machine's keymap.
+
+    This checks both /etc/default/keyboard and /etc/default/console-setup.
+    The former is used by Debian 6.0 (Squeeze) and later.  The latter is
+    used by older versions of Debian, and Ubuntu.
+    """
+
+    KEYBOARD_DEFAULT = "/etc/default/keyboard"
+    paths = [ KEYBOARD_DEFAULT, util.CONSOLE_SETUP_CONF ]
+    for path in paths:
+        kt = find_xkblayout(path)
+        if kt != None:
+            break
+    return kt
+
 #
 # These functions accidentally ended up in the API under virtinst.util
 #
