@@ -535,7 +535,7 @@ def graphics_option_group(parser):
                     action="callback", callback=check_before_store,
       help=_("Specify display configuration. Ex:\n"
              "--graphics vnc\n"
-             "--graphics spice,port=1,tlsport=2\n"
+             "--graphics spice,port=5901,tlsport=5902\n"
              "--graphics none\n"
              "--graphics vnc,password=foobar,port=5910,keymap=ja"))
     vncg.add_option("", "--vnc", action="store_true", dest="vnc",
@@ -695,13 +695,17 @@ def _build_set_param(inst, opts):
 def parse_vcpu_option(guest, optstring, default_vcpus):
     """
     Helper to parse --vcpu string
+
+    @param  guest: virtinst.Guest instance (object)
+    @param  optstring: value of the option '--vcpus' (str)
+    @param  default_vcpus: ? (it should be None at present.)
     """
     vcpus, opts = parse_optstr(optstring, remove_first=True)
     vcpus = vcpus or default_vcpus
 
     set_param = _build_set_param(guest, opts)
     set_cpu_param = _build_set_param(guest.cpu, opts)
-    has_vcpus = ("vcpus" in opts or vcpus)
+    has_vcpus = ("vcpus" in opts or (vcpus is not None))
 
     set_param("vcpus", "vcpus", vcpus)
     set_param("maxvcpus", "maxvcpus")
@@ -718,19 +722,29 @@ def parse_vcpu_option(guest, optstring, default_vcpus):
 
 
 def get_vcpus(vcpus, check_cpu, guest, image_vcpus=None):
-    if vcpus is None and image_vcpus is not None:
-        vcpus = int(image_vcpus)
+    """
+    @param vcpus: value of the option '--vcpus' (str or None)
+    @param check_cpu: Whether to check that the number virtual cpus requested
+                      does not exceed physical CPUs (bool)
+    @param guest: virtinst.Guest instance (object)
+    @param image_vcpus: ? (It's not used currently and should be None.)
+    """
+    if vcpus is None:
+        if image_vcpus is not None:
+            vcpus = image_vcpus
+        else:
+            vcpus = ""
 
     parse_vcpu_option(guest, vcpus, image_vcpus)
 
-    conn = guest.conn
     if check_cpu:
-        hostinfo = conn.getInfo()
-        cpu_num = hostinfo[4] * hostinfo[5] * hostinfo[6] * hostinfo[7]
-        if not vcpus <= cpu_num:
+        hostinfo = guest.conn.getInfo()
+        pcpus = hostinfo[4] * hostinfo[5] * hostinfo[6] * hostinfo[7]
+
+        if guest.vcpus > pcpus:
             msg = _("You have asked for more virtual CPUs (%d) than there "
                     "are physical CPUs (%d) on the host. This will work, "
-                    "but performance will be poor. ") % (vcpus, cpu_num)
+                    "but performance will be poor. ") % (guest.vcpus, pcpus)
             askmsg = _("Are you sure? (yes or no)")
 
             if not prompt_for_yes_or_no(msg, askmsg):
