@@ -98,6 +98,7 @@ DEFAULTS = {
 
         SOUND : {
             "model": [
+                (support.SUPPORT_CONN_HV_SOUND_ICH6, "ich6"),
                 (support.SUPPORT_CONN_HV_SOUND_AC97, "ac97"),
                 (HV_ALL, "es1370"),
             ]
@@ -294,6 +295,12 @@ OS_TYPES = {
                         NET  : VIRTIO_NET,
                         INPUT: USB_TABLET,
                      }},
+        "fedora15": { "label": "Fedora 15", "distro": "fedora",
+                      "devices" : {
+                        DISK : VIRTIO_DISK,
+                        NET  : VIRTIO_NET,
+                        INPUT: USB_TABLET,
+                     }},
 
         "sles10": { "label": "Suse Linux Enterprise Server",
                     "distro": "suse" },
@@ -373,7 +380,20 @@ OS_TYPES = {
             "devices" : {
                 DISK : VIRTIO_DISK,
                 NET  : VIRTIO_NET,
-                INPUT: USB_TABLET,
+            }},
+        "ubuntunatty": {
+            "label": "Ubuntu 11.04 (Natty Narwhal)",
+            "distro": "ubuntu",
+            "devices" : {
+                DISK : VIRTIO_DISK,
+                NET  : VIRTIO_NET,
+            }},
+        "ubuntuoneiric": {
+            "label": "Ubuntu 11.10 (Oneiric Ocelot)",
+            "distro": "ubuntu",
+            "devices" : {
+                DISK : VIRTIO_DISK,
+                NET  : VIRTIO_NET,
             }},
         "generic24": { "label": "Generic 2.4.x kernel" },
         "generic26": { "label": "Generic 2.6.x kernel" },
